==> anipy_cli-3.4.3.tar.gz: anipy_cli-3.4.3/src/anipy_cli/cli.py <==
from typing import Optional

from pypresence.exceptions import DiscordNotFound

from anipy_cli.arg_parser import parse_args
from anipy_cli.clis import *
from anipy_cli.colors import colors, cprint
from anipy_cli.util import error, DotSpinner
from anipy_cli.config import Config
from anipy_cli.discord import DiscordPresence


def run_cli(override_args: Optional[list[str]] = None):
    args = parse_args(override_args)
    config = Config()
    # This updates the config, adding new values doc changes and the like.
    config._create_config()

    if config.dc_presence:
        with DotSpinner("Intializing Discord Presence...") as s:
            try:
                DiscordPresence()
                s.set_text(colors.GREEN, "Initialized Discord Presence")
                s.ok("✔")
            except DiscordNotFound:
                s.set_text(
                    colors.RED,
                    "Discord is not opened, can't initialize Discord Presence",
                )
                s.fail("✘")
            except ConnectionError:
                s.set_text(
                    colors.RED,
                    "Can't Connect to discord, can't initialize Discord Presence",
                )
                s.fail("✘")

    if args.config:
        print(config._config_file)
        return
    elif args.delete:
        try:
            config._history_file_path.unlink()
            cprint(colors.RED, "Done")
        except FileNotFoundError:
            error("no history file found")
        return

    clis_dict = {
        args.download: DownloadCli,
        args.binge: BingeCli,
        args.seasonal: SeasonalCli,
        args.history: HistoryCli,
        args.mal: MalCli,
    }

    cli_class = clis_dict.get(True, DefaultCli)

    try:
        cli_class(options=args).run()
    except KeyboardInterrupt:
        error("interrupted", fatal=True)


if __name__ == "__main__":
    run_cli()

==> anipy_cli-3.5.5.tar.gz: anipy_cli-3.5.5/src/anipy_cli/cli.py <==
from typing import Optional

from pypresence.exceptions import DiscordNotFound

from anipy_api.locallist import LocalList
from anipy_cli.prompts import migrate_provider

from anipy_cli.arg_parser import parse_args
from anipy_cli.clis import *
from anipy_cli.colors import colors, cprint
from anipy_cli.util import error, DotSpinner, migrate_locallist
from anipy_cli.config import Config
from anipy_cli.discord import DiscordPresence


def run_cli(override_args: Optional[list[str]] = None):
    args = parse_args(override_args)
    config = Config()
    # This updates the config, adding new values doc changes and the like.
    config._create_config()

    if config.dc_presence:
        with DotSpinner("Intializing Discord Presence...") as s:
            try:
                DiscordPresence()
                s.set_text(colors.GREEN, "Initialized Discord Presence")
                s.ok("✔")
            except DiscordNotFound:
                s.set_text(
                    colors.RED,
                    "Discord is not opened, can't initialize Discord Presence",
                )
                s.fail("✘")
            except ConnectionError:
                s.set_text(
                    colors.RED,
                    "Can't Connect to discord, can't initialize Discord Presence",
                )
                s.fail("✘")

    if args.config:
        print(config._config_file)
        return
    elif args.delete:
        try:
            config._history_file_path.unlink()
            cprint(colors.RED, "Done")
        except FileNotFoundError:
            error("no history file found")
        return
    elif args.migrate_hist:
        history_list = LocalList(
            Config()._history_file_path, migrate_cb=migrate_locallist
        )
        migrate_provider("default", history_list)
        return

    clis_dict = {
        args.download: DownloadCli,
        args.binge: BingeCli,
        args.seasonal: SeasonalCli,
        args.history: HistoryCli,
        args.mal: MalCli,
    }

    cli_class = clis_dict.get(True, DefaultCli)

    try:
        cli_class(options=args).run()
    except KeyboardInterrupt:
        error("interrupted", fatal=True)


if __name__ == "__main__":
    run_cli()
